@@ -3,11 +3,12 @@
 import argparse
 import sys
 
+from db_contrib_tool.bisect import BisectPlugin
 from db_contrib_tool.setup_repro_env.setup_repro_env import SetupReproEnvPlugin
 from db_contrib_tool.symbolizer.mongosymb import SymbolizerPlugin
 from db_contrib_tool.usage_analytics import track_usage
 
-_PLUGINS = [SetupReproEnvPlugin(), SymbolizerPlugin()]
+_PLUGINS = [BisectPlugin(), SetupReproEnvPlugin(), SymbolizerPlugin()]
 
 
 def parse(sys_args):
